==> jei-1.20.1-fabric-15.20.0.128-sources.jar: mezz/jei/library/plugins/vanilla/crafting/replacers/ShieldDecorationRecipeMaker.java <==
package mezz.jei.library.plugins.vanilla.crafting.replacers;

import mezz.jei.api.constants.ModIds;
import net.minecraft.class_1746;
import net.minecraft.class_1747;
import net.minecraft.class_1767;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1856;
import net.minecraft.class_1867;
import net.minecraft.class_2371;
import net.minecraft.class_2487;
import net.minecraft.class_2591;
import net.minecraft.class_2960;
import net.minecraft.class_3489;
import net.minecraft.class_3955;
import net.minecraft.class_6880;
import net.minecraft.class_7710;
import net.minecraft.class_7923;
import java.util.EnumSet;
import java.util.List;
import java.util.Set;
import java.util.stream.StreamSupport;

public final class ShieldDecorationRecipeMaker {
	public static List<class_3955> createRecipes() {
		Iterable<class_6880<class_1792>> banners = class_7923.field_41178.method_40286(class_3489.field_15556);

		Set<class_1767> colors = EnumSet.noneOf(class_1767.class);

		return StreamSupport.stream(banners.spliterator(), false)
			.filter(class_6880::method_40227)
			.map(class_6880::comp_349)
			.filter(class_1746.class::isInstance)
			.map(class_1746.class::cast)
			.filter(item -> colors.add(item.method_7706()))
			.map(ShieldDecorationRecipeMaker::createRecipe)
			.toList();
	}

	private static class_3955 createRecipe(class_1746 banner) {
		class_2371<class_1856> inputs = class_2371.method_10212(
			class_1856.field_9017,
			class_1856.method_8091(class_1802.field_8255),
			class_1856.method_8091(banner)
		);

		class_1799 output = createOutput(banner);

		class_2960 id = new class_2960(ModIds.MINECRAFT_ID, "jei.shield.decoration." + output.method_7922());
		return new class_1867(id, "jei.shield.decoration", class_7710.field_40251, output, inputs);
	}

	private static class_1799 createOutput(class_1746 banner) {
		class_1767 color = banner.method_7706();
		class_1799 output = new class_1799(class_1802.field_8255);
		class_2487 tag = new class_2487();
		tag.method_10569("Base", color.method_7789());
		class_1747.method_38073(output, class_2591.field_11905, tag);
		return output;
	}

	private ShieldDecorationRecipeMaker() {

	}
}

==> jei-1.21.1-fabric-19.27.0.338-sources.jar: mezz/jei/library/plugins/vanilla/crafting/replacers/ShieldDecorationRecipeMaker.java <==
package mezz.jei.library.plugins.vanilla.crafting.replacers;

import mezz.jei.api.constants.ModIds;
import mezz.jei.common.util.RegistryUtil;
import net.minecraft.class_1746;
import net.minecraft.class_1747;
import net.minecraft.class_1767;
import net.minecraft.class_1792;
import net.minecraft.class_1799;
import net.minecraft.class_1802;
import net.minecraft.class_1856;
import net.minecraft.class_1867;
import net.minecraft.class_2371;
import net.minecraft.class_2487;
import net.minecraft.class_2591;
import net.minecraft.class_2960;
import net.minecraft.class_3489;
import net.minecraft.class_3955;
import net.minecraft.class_6880;
import net.minecraft.class_7710;
import net.minecraft.class_7924;
import net.minecraft.class_8786;
import java.util.EnumSet;
import java.util.List;
import java.util.Set;
import java.util.stream.StreamSupport;

public final class ShieldDecorationRecipeMaker {
	public static List<class_8786<class_3955>> createRecipes() {
		Iterable<class_6880<class_1792>> banners = RegistryUtil.getRegistry(class_7924.field_41197).method_40286(class_3489.field_15556);

		Set<class_1767> colors = EnumSet.noneOf(class_1767.class);

		return StreamSupport.stream(banners.spliterator(), false)
			.filter(class_6880::method_40227)
			.map(class_6880::comp_349)
			.filter(class_1746.class::isInstance)
			.map(class_1746.class::cast)
			.filter(item -> colors.add(item.method_7706()))
			.map(ShieldDecorationRecipeMaker::createRecipe)
			.toList();
	}

	private static class_8786<class_3955> createRecipe(class_1746 banner) {
		class_2371<class_1856> inputs = class_2371.method_10212(
			class_1856.field_9017,
			class_1856.method_8091(class_1802.field_8255),
			class_1856.method_8091(banner)
		);

		class_1799 output = createOutput(banner);

		class_2960 id = class_2960.method_60655(ModIds.MINECRAFT_ID, "jei.shield.decoration." + output.method_7922());
		class_3955 recipe = new class_1867("jei.shield.decoration", class_7710.field_40251, output, inputs);
		return new class_8786<>(id, recipe);
	}

	private static class_1799 createOutput(class_1746 banner) {
		class_1767 color = banner.method_7706();
		class_1799 output = new class_1799(class_1802.field_8255);
		class_2487 tag = new class_2487();
		tag.method_10569("Base", color.method_7789());
		class_1747.method_57338(output, class_2591.field_11905, tag);
		return output;
	}

	private ShieldDecorationRecipeMaker() {

	}
}
